@@ -22,8 +22,8 @@ ply_to_numpy_dtype = {
     # [u]char is often used as [u]int, e.g., from Wikipedia:
     # > The word 'list' indicates that the data is a list of values, the first of which
     # > is the number of entries in the list (represented as a 'uchar' in this case).
-    "char": numpy.int,
-    "uchar": numpy.uint,
+    "char": numpy.int8,
+    "uchar": numpy.uint8,
     "short": numpy.int16,
     "ushort": numpy.uint16,
     "int": numpy.int32,
@@ -88,6 +88,7 @@ def read_buffer(f):
     line = _next_line(f)
     if line == "format ascii 1.0":
         is_binary = False
+        endianness = None
     elif line == "format binary_big_endian 1.0":
         is_binary = True
         endianness = ">"
@@ -216,30 +217,39 @@ def _read_ascii(
         data = line.split()
         if k == 0:
             # initialize the cell data arrays
-            n = []
             i = 0
             cell_data = {}
+            assert len(cell_data_names) == len(cell_dtypes)
             for name, dtype in zip(cell_data_names, cell_dtypes):
-                n = int(data[i])
-                if name != "vertex_indices":
-                    cell_data[name] = []
-                i += n + 1
+                if name == "vertex_indices":
+                    n = int(data[i])
+                    i += n + 1
+                else:
+                    n = 1
+                    cell_data[name] = collections.defaultdict(list)
+                    i += 1
 
         i = 0
         for name, dtype in zip(cell_data_names, cell_dtypes):
-            n = int(data[i])
-            dtype = ply_to_numpy_dtype[dtype[1]]
-            data = [dtype(data[j]) for j in range(i + 1, i + n + 1)]
             if name == "vertex_indices":
-                polygons[n].append(data)
+                n = int(data[i])
+                dtype = ply_to_numpy_dtype[dtype[1]]
+                polygons[n].append([dtype(data[j]) for j in range(i + 1, i + n + 1)])
+                i += n + 1
             else:
-                cell_data[name].append(data)
-            i += n + 1
+                dtype = ply_to_numpy_dtype[dtype]
+                # use n from vertex_indices
+                cell_data[name][n] += [dtype(data[j]) for j in range(i, i + 1)]
+                i += 1
 
     cells = [
         CellBlock(cell_type_from_count(n), numpy.array(data))
         for (n, data) in polygons.items()
     ]
+    cell_data = {
+        key: [numpy.array(v) for v in value.values()]
+        for key, value in cell_data.items()
+    }
 
     return Mesh(verts, cells, point_data=point_data, cell_data=cell_data)
 
@@ -338,7 +348,7 @@ def _read_binary_list(buffer, count_dtype, data_dtype, num_cells, endianness):
     def parse_ragged(start, num_cells):
         at = start
         yield at
-        for i in range(num_cells):
+        for _ in range(num_cells):
             count = int.from_bytes(buffer[at : at + count_itemsize], byteorder)
             at += count * data_itemsize + count_itemsize
             yield at
